pub enum Verdict {
Correct,
Incorrect {
hint: Option<Hint>,
wait: Option<Duration>,
},
Cooldown {
wait: Duration,
},
WrongLevel,
}Expand description
The site’s response to a submitted answer.
Variants
Correct
The answer was accepted, or is the one already accepted for a part that was solved earlier.
Incorrect
The answer was rejected.
Fields
Cooldown
Nothing was judged, because an answer was submitted too recently. This answer still has to be sent again once the wait is over.
WrongLevel
The site was not asking for an answer to that part - either part one is still unsolved, or the part was never a question, which is day 25’s second star.
Implementations