#[non_exhaustive]pub enum ConfigError {
NotFound {
path: PathBuf,
},
Read {
path: PathBuf,
source: Error,
},
Parse {
path: PathBuf,
source: Error,
},
Template {
path: PathBuf,
source: TemplateError,
},
}Expand description
Errors produced while loading configuration.
Non-exhaustive: a future release may add a variant without that being a breaking change, so match with a catch-all arm.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NotFound
No configuration file exists.
Read
The configuration file could not be read.
Parse
The configuration file is not valid YAML, or is missing a required key.
Template
The template_path is not a valid template.