pub struct LanguageCommands {
pub init: Option<CommandSpec>,
pub build: Option<CommandSpec>,
pub run: CommandSpec,
pub run_fallback: Option<CommandSpec>,
}Expand description
The commands used to scaffold, build and run a solution.
Fields
init: Option<CommandSpec>Scaffolding command, if the language needs more than an empty entry file.
build: Option<CommandSpec>Compilation command, if the language is compiled.
run: CommandSpecThe command that executes the solution.
run_fallback: Option<CommandSpec>An alternative to try if LanguageCommands::run’s program is missing.