pub enum ResolveError {
LanguageRequired {
mode: Mode,
},
DayOutOfRange {
year: Year,
day: Day,
},
Template(TemplateError),
}Expand description
Errors produced while resolving a plan.
Variants
LanguageRequired
The mode needs a language and none was given or detected.
DayOutOfRange
The requested day is past the end of the requested event.
Template(TemplateError)
The template could not be compiled into a matcher.